@@ -1,6 +1,6 @@
 // CoreFactory.cc
 //
-// Copyright (C) 2001, 2002, 2003 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,14 +14,12 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: CoreFactory.cc,v 1.1 2004/01/28 12:16:43 dotsphinx Exp $";
+static const char rcsid[] = "$Id: CoreFactory.cc 1090 2006-10-01 20:49:47Z dotsphinx $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "nls.h"
-
 #include "debug.hh"
 #include <assert.h>
 
@@ -29,14 +27,14 @@ static const char rcsid[] = "$Id: CoreFactory.cc,v 1.1 2004/01/28 12:16:43 dotsp
 #include "Configurator.hh"
 #include "Core.hh"
 
-CoreInterface *
+ICore *
 CoreFactory::get_core()
 {
   return Core::get_instance();
 }
 
 
-ConfiguratorInterface *
+IConfigurator *
 CoreFactory::get_configurator()
 {
   Core *core = Core::get_instance();
