@@ -1,6 +1,6 @@
 // DailyLimitWindow.cc --- window for the daily limit
 //
-// Copyright (C) 2001, 2002, 2003, 2004 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2006 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: DailyLimitWindow.cc,v 1.3 2004/11/09 21:08:29 dotsphinx Exp $";
+static const char rcsid[] = "$Id: DailyLimitWindow.cc 1090 2006-10-01 20:49:47Z dotsphinx $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -31,7 +31,7 @@ static const char rcsid[] = "$Id: DailyLimitWindow.cc,v 1.3 2004/11/09 21:08:29
 #include <gtkmm/box.h>
 #include <gtkmm/button.h>
 
-#include "BreakResponseInterface.hh"
+#include "IBreakResponse.hh"
 #include "WindowHints.hh"
 #include "Util.hh"
 #include "Hig.hh"
