@@ -1,6 +1,6 @@
 // GUI.cc --- The WorkRave GUI
 //
-// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006 Rob Caelers & Raymond Penners
+// Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: GUI.cc,v 1.23 2006/05/04 21:01:44 rcaelers Exp $";
+static const char rcsid[] = "$Id: GUI.cc 1144 2007-03-04 18:23:55Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -33,14 +33,16 @@ static const char rcsid[] = "$Id: GUI.cc,v 1.23 2006/05/04 21:01:44 rcaelers Exp
 #include "GUI.hh"
 
 #include "CoreFactory.hh"
-#include "CoreInterface.hh"
-#include "ConfiguratorInterface.hh"
+#include "ICore.hh"
+#include "IConfigurator.hh"
 
-#include "BreakResponseInterface.hh"
+#include "IBreakResponse.hh"
 #include "Dispatcher.hh"
 #include "DailyLimitWindow.hh"
 #include "MainWindow.hh"
-#include "BreakWindowInterface.hh"
+#include "IBreakWindow.hh"
+#include "IBreak.hh"
+#include "ITimer.hh"
 #include "BreakWindow.hh"
 #include "MicroBreakWindow.hh"
 #include "PreludeWindow.hh"
@@ -48,11 +50,19 @@ static const char rcsid[] = "$Id: GUI.cc,v 1.23 2006/05/04 21:01:44 rcaelers Exp
 #include "Util.hh"
 #include "WindowHints.hh"
 #include "System.hh"
-
-#ifdef HAVE_X
+#include "Text.hh"
+#include "AppletControl.hh"
 #include "AppletWindow.hh"
+
+#ifdef WIN32
+#include "W32AppletWindow.hh"
+#include "StatusIcon.hh"
+#include <gdk/gdkwin32.h>
+#include <pbt.h>
 #endif
 
+#include "Menus.hh"
+
 #ifdef HAVE_GCONF
 #include <gconf/gconf-client.h>
 #endif
@@ -61,6 +71,8 @@ static const char rcsid[] = "$Id: GUI.cc,v 1.23 2006/05/04 21:01:44 rcaelers Exp
 
 #ifdef HAVE_GNOME
 #include "RemoteControl.hh"
+#include <bonobo.h>
+#include <bonobo/bonobo-xobject.h>
 #ifdef HAVE_GNOMEMM
 #include "libgnomeuimm/wrap_init.h"
 #endif
@@ -100,10 +112,8 @@ GUI::GUI(int argc, char **argv)  :
   active_prelude_count(0),
   response(NULL),
   active_break_id(BREAK_ID_NONE),
-#ifdef HAVE_X
-  applet_window(NULL),
-#endif  
   main_window(NULL),
+  menus(0),
   tooltips(NULL),
   break_window_destroy(false),
   prelude_window_destroy(false),
@@ -117,7 +127,9 @@ GUI::GUI(int argc, char **argv)  :
 #ifdef HAVE_X
   grab_wanted(false),
 #endif
-  grab_handle(NULL)
+  grab_handle(NULL),
+  status_icon(0),
+  applet_control(NULL)  
 {
   TRACE_ENTER("GUI:GUI");
 
@@ -141,19 +153,22 @@ GUI::~GUI()
 
   ungrab();
   
-  if (core != NULL)
-    {
-      // FIXME: cannot delete interface. delete core;
-    }
-
+  delete core;
   delete main_window;
 
-#ifdef HAVE_X
-  delete applet_window;
-#endif
+  delete applet_control;
+  delete menus;
   
   delete [] prelude_windows;
   delete [] break_windows;
+  delete [] heads;
+  
+  delete sound_player;
+
+#ifdef HAVE_GNOME
+  RemoteControl *control = RemoteControl::get_instance();
+  delete control;
+#endif
   
   TRACE_EXIT();
 }
@@ -195,11 +210,13 @@ GUI::main()
     }
 #endif
 
-  System::init(
 #ifdef HAVE_X
-               gdk_get_display()
+  char *display = gdk_get_display();
+  System::init(display);
+  g_free(display);
+#else
+  System::init();
 #endif
-               );
   
   init_debug();
   init_nls();
@@ -219,10 +236,8 @@ GUI::main()
   delete main_window;
   main_window = NULL;
 
-#ifdef HAVE_X
-  delete applet_window;
-  applet_window = NULL;
-#endif  
+  delete applet_control;
+  applet_control = NULL;
 
 #ifdef WIN32
   // Disable Windows structural exception handling.
@@ -239,6 +254,15 @@ GUI::terminate()
 {
   TRACE_ENTER("GUI::terminate");
 
+#ifdef WIN32
+  // HACK: Without it status icon keeps on dangling in tray
+  // Nicer solution: nicely cleanup complete gui ~GUI()
+  if (status_icon)
+    {
+      delete status_icon;
+      status_icon = 0;
+    }
+#endif
   CoreFactory::get_configurator()->save();
   
   collect_garbage();
@@ -285,6 +309,8 @@ GUI::toggle_main_window()
 bool
 GUI::on_timer()
 {
+  std::string tip = get_timers_tooltip();
+  
   if (core != NULL)
     {
       core->heartbeat();
@@ -295,13 +321,18 @@ GUI::on_timer()
       main_window->update();
     }
 
-#ifdef HAVE_X
-  if (applet_window != NULL)
+  if (applet_control != NULL)
     {
-      applet_window->update();
+      applet_control->heartbeat();
+      applet_control->set_timers_tooltip(tip);
     }
-#endif
-
+  
+#ifdef WIN32  
+  if (status_icon)
+    {
+      status_icon->set_timers_tooltip(tip);
+    }
+#endif  
   heartbeat_signal();
 
   collect_garbage();
@@ -370,9 +401,10 @@ GUI::on_save_yourself(int phase, Gnome::UI::SaveStyle save_style, bool shutdown,
   args.push_back(argv[0] != NULL ? argv[0] : "workrave");
   
   bool skip = false;
-  if (applet_window != NULL)
+
+  if (applet_control != NULL)
     {
-      if (applet_window->get_applet_mode() == AppletWindow::APPLET_GNOME)
+      if (applet_control->is_visible(AppletControl::APPLET_GNOME))
         {
           skip = true;
         }
@@ -411,7 +443,7 @@ GUI::init_kde()
 {
   // FIXME: memory leaks in here.
   TRACE_ENTER("GUI::init_kde");
-  KApplication *a = new KApplication(argc, argv, "Workrave");
+  new KApplication(argc, argv, "Workrave");
   bool rc = kapp->dcopClient()->attach();
   TRACE_MSG(rc);
 
@@ -525,8 +557,8 @@ GUI::init_multihead_mem(int new_num_heads)
 
       delete [] prelude_windows;
       delete [] break_windows;
-      prelude_windows = new PreludeWindow*[num_heads];
-      break_windows = new BreakWindowInterface*[num_heads];
+      prelude_windows = new PreludeWindow*[num_heads];/* LEAK */
+      break_windows = new IBreakWindow*[num_heads]; /* LEAK */
     }
   TRACE_EXIT();
 }
@@ -618,19 +650,42 @@ GUI::init_gtk_multihead()
 #endif        
               {
                 int num_monitors = screen->get_n_monitors();
+                TRACE_MSG("monitors = " << num_monitors);
                 for (int j = 0; j < num_monitors && count < num_heads; j++)
                   {
-                    heads[count].screen = screen;
-                    heads[count].monitor = j;
-                    heads[count].valid = true;
-                    heads[count].count = count;
-              
-                    screen->get_monitor_geometry(j, heads[count].geometry);
+                    Gdk::Rectangle rect;
+                    screen->get_monitor_geometry(j, rect);
 
+                    bool overlap = false;
+                    for (int k = 0; !overlap && k < count; k++)
+                      {
+                        Gdk::Rectangle irect = rect;
+                        irect.intersect(heads[k].geometry, overlap);
+                      }
+
+                    if (!overlap)
+                      {
+                        heads[count].screen = screen;
+                        heads[count].monitor = j;
+                        heads[count].valid = true;
+                        heads[count].count = count;
+
+                        heads[count].geometry = rect;
+                      }
+                    
+                    TRACE_MSG("Screen #" << i << " Monitor #" << j << "  "
+                              << heads[count].geometry.get_x() << " "
+                              << heads[count].geometry.get_y() << " "
+                              << heads[count].geometry.get_width() << " "
+                              << heads[count].geometry.get_height() << " "
+                              << " intersects " << overlap);
+                      
                     count++;
                   }
               }
         }
+      num_heads = count;
+      TRACE_MSG("# Heads = " << num_heads);
     }
   TRACE_EXIT();
 }
@@ -706,12 +761,31 @@ GUI::init_gui()
   tooltips = manage(new Gtk::Tooltips());
   tooltips->enable();
 
+  menus = new Menus();
+  
   // The main status window.
   main_window = new MainWindow();
+
+#ifdef WIN32  
+  // Status icon
+  status_icon = new StatusIcon(*main_window);
+#endif
   
-#ifdef HAVE_X  
   // The applet window.
-  applet_window = new AppletWindow();
+  applet_control = new AppletControl();
+  applet_control->init();
+  
+#ifdef HAVE_GNOME
+  AppletWindow *applet_window = applet_control->get_applet_window(AppletControl::APPLET_GNOME);
+  menus->set_applet_window(applet_window);
+#endif
+#ifdef WIN32
+  AppletWindow *applet_window = applet_control->get_applet_window(AppletControl::APPLET_W32);
+  menus->set_applet_window(applet_window);
+#endif
+  
+#ifdef WIN32
+  win32_init_filter();
 #endif
   
   // Periodic timer.
@@ -748,10 +822,10 @@ GUI::init_remote_control()
 
 
 //! Returns a break window for the specified break.
-BreakWindowInterface *
+IBreakWindow *
 GUI::create_break_window(HeadInfo &head, BreakId break_id, bool ignorable)
 {
-  BreakWindowInterface *ret = NULL;
+  IBreakWindow *ret = NULL;
   BlockMode block_mode = get_block_mode();
   if (break_id == BREAK_ID_MICRO_BREAK)
     {
@@ -774,8 +848,7 @@ GUI::create_break_window(HeadInfo &head, BreakId break_id, bool ignorable)
 void
 GUI::init_sound_player()
 {
-  // FIXME: Memory leak.
-  sound_player = new SoundPlayer();
+  sound_player = new SoundPlayer(); /* LEAK */
 }
 
 
@@ -784,7 +857,7 @@ GUI::core_event_notify(CoreEvent event)
 {
   TRACE_ENTER_MSG("GUI::core_event_notify", event)
   // FIXME: HACK
-  SoundPlayerInterface::Sound snd = (SoundPlayerInterface::Sound) event;
+  ISoundPlayer::Sound snd = (ISoundPlayer::Sound) event;
   if (sound_player != NULL)
     {
       TRACE_MSG("play");
@@ -793,14 +866,27 @@ GUI::core_event_notify(CoreEvent event)
   TRACE_EXIT();
 }
 
+void
+GUI::core_event_operation_mode_changed(const OperationMode m)
+{
+#ifdef WIN32  
+  if (status_icon)
+    status_icon->set_operation_mode(m);
+#else
+  (void) m;
+#endif
+  menus->resync_applet();
+}
+
 
 void
-GUI::set_break_response(BreakResponseInterface *rep)
+GUI::set_break_response(IBreakResponse *rep)
 {
   response = rep;
 }
 
 
+
 void
 GUI::start_prelude_window(BreakId break_id)
 {
@@ -835,13 +921,11 @@ GUI::start_break_window(BreakId break_id, bool ignorable)
 
   for (int i = 0; i < num_heads; i++)
     {
-      BreakWindowInterface *break_window = create_break_window(heads[i], break_id, ignorable);
+      IBreakWindow *break_window = create_break_window(heads[i], break_id, ignorable);
 
       break_windows[i] = break_window;
       
       break_window->set_response(response);
-
-      
       break_window->start();
     }
 
@@ -1005,14 +1089,9 @@ GUI::collect_garbage()
 GUI::BlockMode
 GUI::get_block_mode()
 {
-  bool b;
   int mode;
-  b = CoreFactory::get_configurator()
-    ->get_value(CFG_KEY_GUI_BLOCK_MODE, &mode);
-  if (! b)
-    {
-      mode = BLOCK_MODE_INPUT;
-    }
+  CoreFactory::get_configurator()
+    ->get_value_default(CFG_KEY_GUI_BLOCK_MODE, &mode, BLOCK_MODE_INPUT);
   return (BlockMode) mode;
 }
 
@@ -1228,3 +1307,147 @@ GUI::bound_head(int &x, int &y, int width, int height, int head)
 
   return ret;
 }
+
+
+std::string
+GUI::get_timers_tooltip()
+{
+  //FIXME: duplicate
+  char *labels[] = { _("Micro-break"), _("Rest break"), _("Daily limit") };
+  string tip = "";
+  
+  ICore *core = CoreFactory::get_core();
+  for (int count = 0; count < BREAK_ID_SIZEOF; count++)
+    {
+      IBreak *break_data = core->get_break(BreakId(count));
+      ITimer *timer = break_data->get_timer();
+      bool on = break_data->get_break_enabled();
+
+      if (timer != NULL && on)
+        {
+          // Collect some data.
+          time_t maxActiveTime = timer->get_limit();
+          time_t activeTime = timer->get_elapsed_time();
+          std::string text;
+
+          // Set the text
+          if (timer->is_limit_enabled() && maxActiveTime != 0)
+            {
+              text = Text::time_to_string(maxActiveTime - activeTime);
+            }
+          else
+            {
+              text = Text::time_to_string(activeTime);
+            }
+
+#ifndef WIN32
+          // Win32 tip is limited in length
+          if (tip == "")
+            {
+              tip = "Workrave";
+            }
+#endif
+          if (tip != "")
+            {
+              tip += "\n";
+            }
+          
+          tip += labels[count];
+          tip += ": " + text;
+        }
+    }
+
+  return tip;
+}
+
+
+#ifdef WIN32
+void
+GUI::win32_init_filter()
+{
+  GtkWidget *window = main_window->Gtk::Widget::gobj();
+  GdkWindow *gdk_window = window->window;
+  gdk_window_add_filter(gdk_window, win32_filter_func, this);
+}
+
+GdkFilterReturn
+GUI::win32_filter_func (void     *xevent,
+                        GdkEvent *event,
+                        gpointer  data)
+{
+  TRACE_ENTER("GUI::win32_filter_func");
+  (void) event;
+  GUI *gui = static_cast<GUI*>(data);
+  
+  MSG *msg = (MSG *) xevent;
+  GdkFilterReturn ret = GDK_FILTER_CONTINUE;
+  switch (msg->message)
+    {
+    case WM_POWERBROADCAST:
+      {
+        TRACE_MSG("WM_POWERBROADCAST " << msg->wParam << " " << msg->lParam);
+          switch (msg->wParam)
+            {
+            case PBT_APMQUERYSUSPEND:
+              TRACE_MSG("Query Suspend");
+              break;
+
+            case PBT_APMQUERYSUSPENDFAILED:
+              TRACE_MSG("Query Suspend Failed");
+              break;
+
+            case PBT_APMRESUMESUSPEND:
+              {
+                TRACE_MSG("Resume suspend");
+                ICore *core = CoreFactory::get_core();
+                if (core != NULL)
+                  {
+                    core->set_powersave(false);
+                  }
+              }
+              break;
+
+            case PBT_APMSUSPEND:
+              {
+                TRACE_MSG("Suspend");
+                ICore *core = CoreFactory::get_core();
+                if (core != NULL)
+                  {
+                    core->set_powersave(true);
+                  }
+              }
+              break;
+            }
+      }
+      break;
+
+    case WM_DISPLAYCHANGE:
+      {
+        TRACE_MSG("WM_DISPLAYCHANGE " << msg->wParam << " " << msg->lParam);
+        gui->init_multihead();
+      }
+      break;
+
+    default:
+      W32AppletWindow *applet_window =
+        static_cast<W32AppletWindow*>
+        (gui->applet_control->get_applet_window(AppletControl::APPLET_W32));
+      if (applet_window)
+        {
+          ret = applet_window->win32_filter_func(xevent, event);
+        }
+    }
+
+#ifdef WIN32  
+  if (ret != GDK_FILTER_REMOVE && gui->status_icon)
+    {
+      ret = gui->status_icon->win32_filter_func(xevent, event);
+    }
+#endif  
+
+  TRACE_EXIT();
+  return ret;
+}
+
+
+#endif
