@@ -1,6 +1,6 @@
 // WorkraveApplet.cc
 //
-// Copyright (C) 2002, 2003, 2005 Rob Caelers & Raymond Penners
+// Copyright (C) 2002, 2003, 2005, 2006, 2007 Rob Caelers & Raymond Penners
 // All rights reserved.
 //
 // This program is free software; you can redistribute it and/or modify
@@ -14,7 +14,7 @@
 // GNU General Public License for more details.
 //
 
-static const char rcsid[] = "$Id: RemoteControl.cc,v 1.3 2005/04/30 22:42:14 rcaelers Exp $";
+static const char rcsid[] = "$Id: RemoteControl.cc 1129 2007-02-12 22:21:00Z rcaelers $";
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -25,7 +25,8 @@ static const char rcsid[] = "$Id: RemoteControl.cc,v 1.3 2005/04/30 22:42:14 rca
 #include "RemoteControl.hh"
 
 #include "GUI.hh"
-#include "AppletWindow.hh"
+#include "AppletControl.hh"
+#include "GnomeAppletWindow.hh"
 
 #include "Menus.hh"
 
@@ -47,6 +48,10 @@ RemoteControl::RemoteControl()
 
 RemoteControl::~RemoteControl()
 {
+  // FIXME: this causes sme vague error.
+  // g_object_unref(workrave_control);
+  workrave_control = NULL;
+  instance = NULL;
 }
 
 
@@ -59,7 +64,6 @@ RemoteControl::get_instance()
 
       if (control != NULL)
         {
-          // FIXME: Memory leak.
           instance = new RemoteControl();
           
           instance->workrave_control = control;
@@ -73,16 +77,17 @@ RemoteControl::get_instance()
 
 WR_METHOD_ARGS0_IMPL(void, fire)
 {
-  GUI *gui = GUI::get_instance();
+  AppletControl *applet_control; 
+  GnomeAppletWindow *applet_window;
+  GUI *gui;
 
-  AppletWindow *applet = NULL;
-  if (gui != NULL)
+  gui = GUI::get_instance();
+  applet_control = gui->get_applet_control();
+  applet_window = (GnomeAppletWindow *) applet_control->get_applet_window(AppletControl::APPLET_GNOME);
+  
+  if (applet_window != NULL)
     {
-      applet = gui->get_applet_window();
-    }
-  if (applet != NULL)
-    {
-      applet->fire_gnome_applet();
+      applet_window->fire_gnome_applet();
     }
 }
 
@@ -162,6 +167,7 @@ WR_METHOD_ARGS0_IMPL(void, restbreak)
 WR_METHOD_ARGS1_IMPL(void, set_mode, GNOME_Workrave_WorkraveControl_Mode, mode)
 {
   Menus *menus = Menus::get_instance();
+  TRACE_ENTER_MSG("RemoteControl::set_mode", mode);
   if (menus != NULL)
     {
       switch (mode)
@@ -179,6 +185,7 @@ WR_METHOD_ARGS1_IMPL(void, set_mode, GNOME_Workrave_WorkraveControl_Mode, mode)
           break;
         }
     }
+  TRACE_EXIT();
 }
 
 
@@ -212,59 +219,90 @@ WR_METHOD_ARGS0_IMPL(void, quit)
 }
 
 
-WR_METHOD_ARGS1_IMPL(void, set_applet_vertical, CORBA_boolean, vertical)
+WR_METHOD_ARGS1_IMPL(void, set_applet_orientation, CORBA_long, orientation)
 {
-  GUI *gui = GUI::get_instance();
+  AppletControl *applet_control; 
+  GnomeAppletWindow *applet_window;
+  GUI *gui;
 
-  AppletWindow *applet = NULL;
-  if (gui != NULL)
+  gui = GUI::get_instance();
+  applet_control = gui->get_applet_control();
+  applet_window = (GnomeAppletWindow *) applet_control->get_applet_window(AppletControl::APPLET_GNOME);
+
+  if (applet_window != NULL)
     {
-      applet = gui->get_applet_window();
-    }
-  if (applet != NULL)
-    {
-      applet->set_applet_vertical(vertical);
+      applet_window->set_applet_orientation((Orientation)orientation);
     }
 }
 
 
+WR_METHOD_ARGS3_IMPL(void, set_applet_background,
+                     CORBA_long, type,
+                     const GNOME_Workrave_WorkraveControl_Color *, color,
+                     CORBA_long, xid)
+{
+  AppletControl *applet_control; 
+  GnomeAppletWindow *applet_window;
+  GUI *gui;
+
+  gui = GUI::get_instance();
+  applet_control = gui->get_applet_control();
+  applet_window = (GnomeAppletWindow *) applet_control->get_applet_window(AppletControl::APPLET_GNOME);
+  
+  if (applet_window != NULL)
+    {
+      GdkColor gdk_color;
+      
+      if (color != NULL)
+        {
+          gdk_color.pixel = color->pixel;
+          gdk_color.red = color->red;
+          gdk_color.green = color->green;
+          gdk_color.blue = color->blue;
+        }
+        
+      applet_window->set_applet_background(type, gdk_color, xid);
+    }
+}
+
 WR_METHOD_ARGS1_IMPL(void, set_applet_size, CORBA_long, size)
 {
-  GUI *gui = GUI::get_instance();
+  AppletControl *applet_control; 
+  GnomeAppletWindow *applet_window;
+  GUI *gui;
 
-  AppletWindow *applet = NULL;
-  if (gui != NULL)
+  gui = GUI::get_instance();
+  applet_control = gui->get_applet_control();
+  applet_window = (GnomeAppletWindow *) applet_control->get_applet_window(AppletControl::APPLET_GNOME);
+  
+  if (applet_window != NULL)
     {
-      applet = gui->get_applet_window();
-    }
-  if (applet != NULL)
-    {
-      applet->set_applet_size(size);
+      applet_window->set_applet_size(size);
     }
 }
 
 
-WR_METHOD_ARGS1_IMPL(void, set_applet, Bonobo_Unknown, applet_control)
+WR_METHOD_ARGS1_IMPL(void, set_applet, Bonobo_Unknown, bonobo_applet_control)
 {
   TRACE_ENTER("set_applet");
-  GUI *gui = GUI::get_instance();
+  AppletControl *applet_control; 
+  GnomeAppletWindow *applet_window;
+  GUI *gui;
 
-  AppletWindow *applet = NULL;
-  if (gui != NULL)
-    {
-      applet = gui->get_applet_window();
-    }
-
-  if (applet != NULL)
+  gui = GUI::get_instance();
+  applet_control = gui->get_applet_control();
+  applet_window = (GnomeAppletWindow *) applet_control->get_applet_window(AppletControl::APPLET_GNOME);
+  
+  if (applet_window != NULL)
     {
       GNOME_Workrave_AppletControl c =
-        Bonobo_Unknown_queryInterface(applet_control,
+        Bonobo_Unknown_queryInterface(bonobo_applet_control,
                                       "IDL:GNOME/Workrave/AppletControl:1.0",
                                       NULL);
       
       if (c != CORBA_OBJECT_NIL)
         {
-          applet->set_applet_control(c);
+          applet_window->set_applet_control(c);
         }
       TRACE_MSG(c);
     }
@@ -275,19 +313,17 @@ WR_METHOD_ARGS1_IMPL(void, set_applet, Bonobo_Unknown, applet_control)
 WR_METHOD_ARGS1_IMPL(void, button_clicked, CORBA_long, button)
 {
   TRACE_ENTER_MSG("button_clicked", button);
+  AppletControl *applet_control; 
+  GnomeAppletWindow *applet_window;
+  GUI *gui;
 
-  GUI *gui = GUI::get_instance();
-  assert(gui != NULL);
+  gui = GUI::get_instance();
+  applet_control = gui->get_applet_control();
+  applet_window = (GnomeAppletWindow *) applet_control->get_applet_window(AppletControl::APPLET_GNOME);
   
-  AppletWindow *applet = NULL;
-  if (gui != NULL)
+  if (applet_window != NULL)
     {
-      applet = gui->get_applet_window();
-    }
-
-  if (applet != NULL)
-    {
-      applet->button_clicked(button);
+      applet_window->button_clicked(button);
     }
   TRACE_EXIT();
 }
@@ -323,9 +359,10 @@ workrave_control_class_init(WorkraveControlClass *klass)
   WR_METHOD_REGISTER(reconnect_all);
   WR_METHOD_REGISTER(quit);
 
-  WR_METHOD_REGISTER(set_applet_vertical);
+  WR_METHOD_REGISTER(set_applet_orientation);
   WR_METHOD_REGISTER(set_applet_size);
   WR_METHOD_REGISTER(set_applet);
+  WR_METHOD_REGISTER(set_applet_background);
   WR_METHOD_REGISTER(button_clicked);
 }
 
