@@ -13,7 +13,7 @@
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
-// $Id: ExercisesPanel.cc,v 1.6 2006/05/12 21:07:35 rcaelers Exp $
+// $Id: ExercisesPanel.cc 1109 2006-11-13 19:16:52Z rcaelers $
 //
 
 #include "config.h"
@@ -30,7 +30,7 @@
 #include "Util.hh"
 #include "Hig.hh"
 #include "nls.h"
-#include "SoundPlayerInterface.hh"
+#include "ISoundPlayer.hh"
 #include "debug.hh"
 
 // This code can be removed once the following bug is closed:
@@ -237,13 +237,13 @@ ExercisesPanel::ExercisesPanel(Gtk::HButtonBox *dialog_action_area)
     }
   else
     {
-      back_button =  GtkUtil::create_custom_stock_button
-        (NULL, Gtk::Stock::GO_BACK);
-      forward_button =  GtkUtil::create_custom_stock_button
-        (NULL, Gtk::Stock::GO_FORWARD);
+      back_button = manage(GtkUtil::create_custom_stock_button
+                           (NULL, Gtk::Stock::GO_BACK));
+      forward_button =  manage(GtkUtil::create_custom_stock_button
+                               (NULL, Gtk::Stock::GO_FORWARD));
       
-      Gtk::Button *stop_button =  GtkUtil::create_custom_stock_button
-        (NULL, Gtk::Stock::CLOSE);
+      Gtk::Button *stop_button =  manage(GtkUtil::create_custom_stock_button
+                                         (NULL, Gtk::Stock::CLOSE));
       stop_button->signal_clicked()
         .connect(MEMBER_SLOT(*this, &ExercisesPanel::on_stop));
 
@@ -308,10 +308,12 @@ ExercisesPanel::on_realize()
 
 ExercisesPanel::~ExercisesPanel()
 {
+  TRACE_ENTER("ExercisesPanel::~ExercisesPanel");
   if (heartbeat_signal.connected())
     {
       heartbeat_signal.disconnect();
     }
+  TRACE_EXIT();
 }
 
 void
@@ -334,22 +336,27 @@ ExercisesPanel::reset()
 void
 ExercisesPanel::start_exercise()
 {
-  const Exercise &exercise = *exercise_iterator;
-  Glib::RefPtr<Gtk::TextBuffer> buf = description_text.get_buffer();
-  std::string txt = HigUtil::create_alert_text(exercise.title.c_str(),
-                                                 exercise.description.c_str());
-  text_buffer_set_markup(buf->gobj(), txt.c_str(), txt.length());
-  exercise_time = 0;
-  seq_time = 0;
-  image_iterator = exercise.sequence.end();
-  refresh_progress();
-  refresh_sequence();
+  if (exercises.size() > 0)
+    {
+      const Exercise &exercise = *exercise_iterator;
+
+      Glib::RefPtr<Gtk::TextBuffer> buf = description_text.get_buffer();
+      std::string txt = HigUtil::create_alert_text(exercise.title.c_str(),
+                                                   exercise.description.c_str());
+      text_buffer_set_markup(buf->gobj(), txt.c_str(), txt.length());
+      exercise_time = 0;
+      seq_time = 0;
+      image_iterator = exercise.sequence.end();
+      refresh_progress();
+      refresh_sequence();
+    }
 }
 
 void
 ExercisesPanel::show_image()
 {
   TRACE_ENTER("ExercisesPanel::show_image");
+
   const Exercise::Image &img = (*image_iterator);
   seq_time += img.duration;
   TRACE_MSG("image=" << img.image);
@@ -365,22 +372,26 @@ ExercisesPanel::show_image()
       Glib::RefPtr<Gdk::Pixbuf> flip = GtkUtil::flip_pixbuf(pixbuf, true, false);
       image.set(flip);
     }
+
   TRACE_EXIT();
 }
 
 void
 ExercisesPanel::refresh_sequence()
 {
-  if (exercise_time >= seq_time)
+  TRACE_ENTER("ExercisesPanel::refresh_sequence");
+  const Exercise &exercise = *exercise_iterator;
+  if (exercise_time >= seq_time && exercise.sequence.size() > 0)
     {
       image_iterator++;
-      const Exercise &exercise = *exercise_iterator;
       if (image_iterator == exercise.sequence.end())
         {
           image_iterator = exercise.sequence.begin();
         }
       show_image();
     }
+
+  TRACE_EXIT();
 }
 
 void
@@ -450,21 +461,24 @@ ExercisesPanel::heartbeat()
 {
   if (paused || stopped)
     return;
+
+  if (exercises.size() == 0)
+    return;
   
   const Exercise &exercise = *exercise_iterator;
   exercise_time++;
   if (exercise_time >= exercise.duration)
     {
       on_go_forward();
-      SoundPlayerInterface *snd = GUI::get_instance()->get_sound_player();
+      ISoundPlayer *snd = GUI::get_instance()->get_sound_player();
       exercise_num++;
       if (exercise_num == exercise_count)
         {
           on_stop();
         }
       snd->play_sound(stopped
-                      ? SoundPlayerInterface::SOUND_EXERCISES_ENDED
-                      : SoundPlayerInterface::SOUND_EXERCISE_ENDED);
+                      ? ISoundPlayer::SOUND_EXERCISES_ENDED
+                      : ISoundPlayer::SOUND_EXERCISE_ENDED);
     }
   else
     {
